##  Setting a Template as Default
Admins can designate any template as the default. This ensures that the preferred shape template automatically appears as the default choice while working in the diagram editor.
To set a template as the default, do the following:
  1. In the Diagrams tab, select Fact Sheet Shape Templates from the left-side panel.
  2. Click the three-dot menu at the bottom of the desired template and select Set as Default.
